//
//	DAYTime.h -- a generic class to simplify manipulation of times
//		Written by Don Yacktman (c) 1993 by Don Yacktman.
//				Version 1.0.  All rights reserved.
//
//		This is a free object!  Contact the author for the latest version.
//		Don Yacktman, 4279 N. Ivy Lane, Provo, UT, 84604
//		e-mail:  Don_Yacktman@byu.edu
//
//	See DAYTime.m for details of the software license.
//

#import <appkit/appkit.h>

#define DAY_UNKNOWN_DOW -1	// for uncalced day of week
#define DAY_MAX_MICROSECONDS 1000000
#define DAY_MAX_SECONDS 60
#define DAY_MAX_MINUTES 60
#define DAY_MAX_HOURS 24
#define DAY_MAX_DAYS 365
#define DAY_MAX_MONTHS 12

@interface DAYTime:Object <NXTransport>
{
	BOOL isRelative; // if we are absolute date or a relative measure.
	long microsecond, second, minute, hour, dow, day, month, year;
	char *myStringValue;
	@private BOOL _initted;
}

- init;
- initWithCurrentTime;

- setYear:(int)t;
- setMonth:(int)t;
- setDayOfWeek:(int)t;
- calcDayOfWeek;		// set the year, month, and day first.
- setDay:(int)t;
- setHour:(int)t;
- setMinute:(int)t;
- setSecond:(int)t;
- setMicrosecond:(int)t;
- setRelative:(BOOL)t;
- (BOOL)isRelative;

- (int)_nintValue; // private method, does intValue w/o usecs.
- (int)intValue;
- (float)floatValue;
- (double)doubleValue;
- (const char *)stringValue;

- (int)year;
- (int)month;
- (int)dayOfWeek;
- (int)day;
- (int)hour;
- (int)minute;
- (int)second;
- (int)microsecond;

- addTime:aTime;
- subtractTime:aTime;

- addMicroseconds:(long)t;
- addSeconds:(long)t;
- addMinutes:(long)t;
- addHours:(long)t;
- addDays:(long)t;
- addWeeks:(long)t;
- addMonths:(long)t;
- addYears:(long)t;

- subtractMicroseconds:(long)t;
- subtractSeconds:(long)t;
- subtractMinutes:(long)t;
- subtractHours:(long)t;
- subtractDays:(long)t;
- subtractWeeks:(long)t;
- subtractMonths:(long)t;
- subtractYears:(long)t;

- (BOOL)isAfter:aTime;
- (BOOL)isEqual:aTime;

- copy;
- copyTimeFrom:aTime;
- read:(NXTypedStream *)stream;
- write:(NXTypedStream *)stream;

@end
